#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-cabal-fmt-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-cabal-fmt-plugin-2.3.0.0-5Reymqw6g2RIOxVMOnqqc7
key:                  hls-cabal-fmt-plugin-2.3.0.0-5Reymqw6g2RIOxVMOnqqc7
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           jana.chadt@nets.at
author:               The Haskell IDE Team
synopsis:             Integration with the cabal-fmt code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  ce0f9891211bd6cf33e2d1317bb3e006
exposed:              True
exposed-modules:      Ide.Plugin.CabalFmt
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-cabal-fmt-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-cabal-fmt-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-cabal-fmt-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-cabal-fmt-plugin
hs-libraries:         HShls-cabal-fmt-plugin-2.3.0.0-5Reymqw6g2RIOxVMOnqqc7
depends:
    base-4.18.2.1 directory-1.3.8.5 filepath-1.4.300.1
    ghcide-2.3.0.0-LunlqcUGsjt6Z8onRREW7F
    hls-plugin-api-2.3.0.0-HgW1tAxOhuJCw3pTb3Klag
    lens-5.3.4-6Y9sfkt8OEM3cWxRkkF9y8
    lsp-types-2.0.2.0-B5120DC53MD78pBpYoN9J2 mtl-2.3.1
    process-extras-0.7.4-BPQSjsOtD02KBJqcwlv7qi text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-hls-cabal-fmt-plugin/html/hls-cabal-fmt-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-cabal-fmt-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

